<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicació de servidor intermediari</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Marqueu «Usa un servidor intermediari» al menú contextual de l&apos;aplicació al llançador després d&apos;haver-lo configurat.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port no vàlid</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Desconnecta</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconnecta</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Segur que voleu eliminar aquesta configuració?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Connexió amb fil %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Punt d&apos;accés</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Connexió sense fil %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Connexió PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>XPV nova</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipus d&apos;XPV</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>XPV L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>XPV PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>XPV VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>XPV OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>XPV StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>XPV OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicació de servidor intermediari</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Punt d&apos;accés personal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalls de xarxa</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptador de la xarxa amb fil</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Afegiu una connexió de xarxa</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptador de la xarxa sense fil</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connecta amb una xarxa oculta</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crea una connexió de PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Estat de la XPV</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crea una XPV</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importa una XPV</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuració</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Punt d&apos;accés</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Crea un punt d&apos;accés</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfície</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primari</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocitat</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Habilitar el mode d&apos;avió inhabilita la xarxa sense fil, el punt d&apos;accés personal i el Bluetooth.</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Adreça DNS no vàlida</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Sense vincle</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adreça MAC del dispositiu</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adreça MAC clonada</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalitzeu l&apos;MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>El nom ja existeix.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Connexió automàtica</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Punt d&apos;accés</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Afegiu paràmetres</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Crea un punt d&apos;accés</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adreça IP duplicada</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Màscara de xarxa no vàlida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Només es permet una passarel·la.</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adreça IP duplicada</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Només es permet una passarel·la.</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adreça IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Només s&apos;aplica als recursos corresponents</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Mètode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adreça IP no vàlida</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>màscara de xarxa no vàlida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Mètode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora-ho</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detalls de la xarxa</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicació de servidor intermediari</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalls de la xarxa</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configureu-ho amb el gestor de xarxes</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Punt d&apos;accés personal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servei</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sense compressió de dades de BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sense compressió de dades amb deflació</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sense compressió de capçalera TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sense compressió de camp de protocol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sense compressió d&apos;adreça / control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envia paquets PPP Echo</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usa MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE de 128 bits</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE amb estat</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crea una connexió de PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Servidor intermediari del sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Servidor intermediari d&apos;HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Servidor intermediari d&apos;HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Servidor intermediari d&apos;FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Servidor intermediari de SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignora les configuracions d&apos;intermediari per als amfitrions i dominis anteriors.</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuració</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>SALT</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>Ràpid</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS per túnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegit</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Desa la contrasenya per a aquest usuari.</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Desa la contrasenya per a tots els usuaris.</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pregunta-m&apos;ho sempre.</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anònim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticat</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambdós</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versió 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versió 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticació d&apos;EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitat</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcions de la contrasenya</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clau privada</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificat d&apos;usuari</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anònim</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Aprovisionament</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Fitxer PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticació interna</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versió PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contrasenya privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Contrasenya no vàlida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clau</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Cal seguretat</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Contrasenya no vàlida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA / WPA2 d&apos;empresa</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clau compartida</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Obre el sistema</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticació</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clau</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>XPV avançada</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalitzeu el port de la passarel·la</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port de la passarel·la</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalitzeu l&apos;interval de renegociació</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval de renegociació</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Usa compressió de dades LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usa una connexió TCP.</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usa un dispositiu TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalitzeu el túnel d&apos;MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalitzeu la mida de fragment d&apos;UPD</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Mida de fragment d&apos;UPD</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringeix el túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Fes aleatoris els amfitrions remots</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>XPV avançada</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (per defecte)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Segur (per defecte)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Dèbil</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T quan estigui disponible (per defecte)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T sempre</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Grup DH  1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Grup DH 2 (per defecte)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Grup DH 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (per defecte)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Grup DH 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domini</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Proveïdor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versió</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Encriptació</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mode Traversal de NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grup IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Secretisme de reenviament</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Inhabilita la detecció de màquines mortes.</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>XPV IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activa l&apos;IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nom del grup</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID del grup</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clau precompartida</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmes de fase 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmes de fase 2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Servidor intermediari</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permet Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificat d&apos;usuari</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clau privada</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Usa FSID per a la contrasenya</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificats (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificats amb contrasenya (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Clau estàtica</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>S&apos;ha desat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No cal</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipus d&apos;autenticació</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificat d&apos;usuari</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clau privada</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcions de la contrasenya</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contrasenya privada</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalitzeu la direcció de la clau</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direcció de la clau</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP remota</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>XPV PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tot el disponible (per defecte)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 bits (menys segur)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 bits (més segur)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació de CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Rebutja l&apos;autenticació MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Rebutja l&apos;autenticació d&apos;MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sense compressió de dades de BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sense compressió de dades amb deflació</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sense compressió de capçalera TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sense compressió de camp de protocol</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sense compressió d&apos;adreça / control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envia paquets PPP Echo</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usa MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE amb estat</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Estat de la XPV</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crea una XPV</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importa una XPV</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Error d&apos;importació</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Error del fitxer</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Servidor intermediari d&apos;XPV</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No cal</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipus de servidor intermediari</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP del servidor</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Torna a intentar-ho indefinidament quan falli.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Fitxer de CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignora els avisos de certificats.</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Usa extensions del nom d&apos;amfitrió TLS.</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Seguretat de la XPV</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Xifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticació HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>S&apos;ha desat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No cal</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcions de la contrasenya</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domini d&apos;NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Servidor intermediari d&apos;XPV</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP del servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clau privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent d&apos;SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Targeta intel·ligent</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clau precompartida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificat CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipus d&apos;autenticació</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificat d&apos;usuari</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Demana una adreça IP interna</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Força l&apos;encapsulació d&apos;UPD</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usa la compressió d&apos;IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activa les propostes personalitzades de xifrat</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticació d&apos;XPV TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Coincidència d&apos;assumpte</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipus de certificat remot</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Fitxer de clau</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalitzeu la direcció de la clau</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direcció de la clau</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>XPV</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passarel·la no vàlida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>S&apos;ha desat</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No cal</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcions de la contrasenya</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nom del grup</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Contrasenya del grup</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Usa l&apos;autenticació híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Fitxer de CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Connecteu primer el cable de xarxa.</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptador de la xarxa amb fil</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Afegiu una connexió de xarxa</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Seleccioneu els paràmetres</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptador de la xarxa sense fil</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Tanca el punt d&apos;accés.</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Inhabiliteu primer el punt d&apos;accés si voleu connectar-vos a una xarxa sense fil.</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connecta amb una xarxa oculta</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Sense vincle</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adreça MAC del dispositiu</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalitzeu l&apos;MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punt d&apos;accés</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipus de seguretat</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfície</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primari</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositiu inhabilitat</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connectat però sense accés a Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de xarxa desendollat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>S&apos;autentica</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>S&apos;obté l&apos;adreça IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connectat</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconnectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ha fallat</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>S&apos;obté l&apos;adreça</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Xarxa amb fil %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Xarxa sense fil %1</translation>
    </message>
</context>
</TS>